# Changelog

## [0.1.3](https://github.com/agntcy/agp/compare/agp-bindings-v0.1.2...agp-bindings-v0.1.3) (2025-02-13)


### Features

* **python-wheels:** add aarch64 build ([#37](https://github.com/agntcy/agp/issues/37)) ([7631f4e](https://github.com/agntcy/agp/commit/7631f4ea1425b40fd8139270ea51785463fad22e))

## [0.1.2](https://github.com/agntcy/agp/compare/agp-bindings-v0.1.1...agp-bindings-v0.1.2) (2025-02-12)


### Bug Fixes

* python bindings import name ([#24](https://github.com/agntcy/agp/issues/24)) ([5f5e7c6](https://github.com/agntcy/agp/commit/5f5e7c6a823a3e842d13d326436cbdc73c64bacf))

## [0.1.1](https://github.com/agntcy/agp/compare/agp-bindings-v0.1.0...agp-bindings-v0.1.1) (2025-02-11)


### Features

* improve readme for pypi release ([#19](https://github.com/agntcy/agp/issues/19)) ([23dfa5c](https://github.com/agntcy/agp/commit/23dfa5cbd20c96a35e62d40a0808c3268b177f8b))
* include readme in published pypi package ([#18](https://github.com/agntcy/agp/issues/18)) ([5a26dea](https://github.com/agntcy/agp/commit/5a26dea6ece36124ed88861bc32fe7eea4aea184))

## [0.1.0](https://github.com/agntcy/agp/compare/agp-bindings-v0.0.0...agp-bindings-v0.1.0) (2025-02-11)


### Features

* automate python packages release ([#16](https://github.com/agntcy/agp/issues/16)) ([f806256](https://github.com/agntcy/agp/commit/f8062564c8451767c5b38fedce38c520c8c216ac))
